==> sight_21.0.0.orig.tar.gz: sight-21.0.0/libs/core/data/test/tu/RawBufferTLTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2021 IRCAD France
 * Copyright (C) 2012-2016 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::data
{

namespace ut
{

class RawBufferTLTest : public CPPUNIT_NS::TestFixture
{
public:

    CPPUNIT_TEST_SUITE(RawBufferTLTest);
    CPPUNIT_TEST(pushTest);
    CPPUNIT_TEST(getObjectTest);
    CPPUNIT_TEST(setObjectTest);
    CPPUNIT_TEST(modifyTimeTest);
    CPPUNIT_TEST(copyTest);
    CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp();
    void tearDown();

    void pushTest();
    void getObjectTest();
    void setObjectTest();
    void modifyTimeTest();
    void copyTest();
};

} //namespace ut

} //namespace sight::data

==> sight_23.1.0.orig.tar.gz: sight-23.1.0/libs/core/data/test/tu/RawBufferTLTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2022 IRCAD France
 * Copyright (C) 2012-2016 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::data::ut
{

class RawBufferTLTest : public CPPUNIT_NS::TestFixture
{
public:

    CPPUNIT_TEST_SUITE(RawBufferTLTest);
    CPPUNIT_TEST(pushTest);
    CPPUNIT_TEST(getObjectTest);
    CPPUNIT_TEST(setObjectTest);
    CPPUNIT_TEST(modifyTimeTest);
    CPPUNIT_TEST(copyTest);
    CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp() override;
    void tearDown() override;

    static void pushTest();
    static void getObjectTest();
    static void setObjectTest();
    static void modifyTimeTest();
    static void copyTest();
};

} // namespace sight::data::ut
